@@ -17,9 +17,12 @@ usage:
 """
 
 __title__ = 'internetarchive'
-__version__ = '0.3.4'
+__version__ = '0.3.6'
 __author__ = 'Jacob M. Johnson'
 __license__ = 'GPL'
 __copyright__ = 'Copyright 2013 Jacob M. Johnson'
 
-from .internetarchive import Item, File, Catalog, Search, Mine
+from .item import Item, File
+from .service import Search, Catalog
+from .mine import Mine
+from .api import *
